
%% Initial Parameter Setting

%% Design Target: Hyperuniformity & Anti-Hyperuniformity / Preference Design
HU_aHU=1;
prefer_type=4;
['Dynamic Preferential Attachment! Type: ',num2str(prefer_type,'%02i')]

%% Spatial Domain Definition
NN=500;  %% Particle Number
DD=2;   %% System Dimension
NN_pre=1;  %% Pre-assigned Particle Number (Poisson Distribution)
NN_post=0;  %% Post-assigned Particle Number (Poisson Distribution)

%% Real Space Definition
RR_max=1;   %% Radius for Full Space
RR_ROI_max=1.0;   %% Maximum Radial Position for the region of interest (ROI)
RR_ROI_min=0.0;   %% Minimum Radial Position for the region of interest (ROI)
VV_max=(pi.^(DD/2))./gamma(DD./2+1)*(RR_max.^DD);   %% Volume of a d-dimensional Euclidean ball
VV_ROI_max=(pi.^(DD/2))./gamma(DD./2+1)*(RR_ROI_max.^DD);   %% Volume of a d-dimensional Euclidean ball for RR_ROI_max
VV_ROI_min=(pi.^(DD/2))./gamma(DD./2+1)*(RR_ROI_min.^DD);   %% Volume of a d-dimensional Euclidean ball for RR_ROI_min
VV_ROI=VV_ROI_max-VV_ROI_min;   %% Volume of ROI

rr_a=(NN.^(-1./DD)).*RR_max;    %% Radius of an averaged unit volume for each particle
dd_a=2*rr_a;    %% Characteristic Length: Average Distance between Point Particles    
DD_factor_k=(NN.^(1./DD));

%% Reciprocal Space Definition
km_max=1;   %% Radius for Full k-space
km_ROI_max=0.50;
km_ROI_min=0.05;
VV_max_kk=(pi.^(DD/2))./gamma(DD./2+1)*(km_max.^DD);   %% Volume of a d-dimensional Euclidean ball
VV_ROI_max_kk=(pi.^(DD/2))./gamma(DD./2+1)*(km_ROI_max.^DD);   %% Volume of a d-dimensional Euclidean ball for km_ROI_max
VV_ROI_min_kk=(pi.^(DD/2))./gamma(DD./2+1)*(km_ROI_min.^DD);   %% Volume of a d-dimensional Euclidean ball for km_ROI_min
VV_ROI_kk=VV_ROI_max_kk-VV_ROI_min_kk;   %% Volume of ROI

kk_unit=2.*pi./dd_a;
kk_max=km_max.*kk_unit; %% = km_max.*DD_factor_k.*pi./RR_max = km_max.*(NN.^(1./DD)).*pi./RR_max;
kk_ROI_max=km_ROI_max.*kk_unit; %% = km_ROI_max.*DD_factor_k.*pi./RR_max = km_ROI_max.*(NN.^(1./DD)).*pi./RR_max;
kk_ROI_min=km_ROI_min.*kk_unit; %% = km_ROI_min.*DD_factor_k.*pi./RR_max = km_ROI_min.*(NN.^(1./DD)).*pi./RR_max;

%% Monte Carlo Definition
pdf_approx_discrete=4e4;    %% Discretization for approximating probability density functions
monte_num_RR_max=1e4;
monte_num_km_max=1e4;
ang_rr_st=0;
ang_rr_ed=2.*pi;
ang_kk_st=0;
ang_kk_ed=pi;


%% Pre-/Post-Particle Position
rr_vec=zeros(NN,DD);    %% Full Position Information
rr_vec_init=[0,0];  %% Initial Particle Position (for NN_pre=1)

% Restriction on Pre-Particle Positions
RR_init_min=RR_ROI_min;
RR_init_max=RR_ROI_max;

% Restriction on Post-Particle Positions
RR_post_min=RR_ROI_min;
RR_post_max=RR_ROI_max;

if NN_pre<2
    if RR_init_min>0
        init_dist_update;
        rr_vec(1:1:NN_pre,:)=rr_vec_cand_init;
    else
        rr_vec(1,:)=rr_vec_init;
    end
else
    init_dist_update;
    rr_vec(1:1:NN_pre,:)=rr_vec_cand_init;
end

%% Generative Design
% Random Parameter
rng_param=rng_sim;
rng(rng_param);






